@@ -35,9 +35,10 @@ class KuyrukTestCase(unittest.TestCase):
     def test_another_queue(self):
         """Run a task on different queue"""
         tasks.print_task2('hello another')
-        with run_kuyruk(queues='another_queue') as master:
+        with run_kuyruk(queue='another_queue') as master:
             master.expect('another_queue')
             master.expect('hello another')
+            master.expect('Committed transaction')
 
     def test_exception(self):
         """Errored task message is discarded"""
@@ -58,7 +59,7 @@ class KuyrukTestCase(unittest.TestCase):
         """If the worker is stuck on the task it can be stopped by
         invoking cold shutdown"""
         tasks.loop_forever()
-        with run_kuyruk(terminate=False) as master:
+        with run_kuyruk(process='master', terminate=False) as master:
             master.expect('looping forever')
             master.send_signal(signal.SIGINT)
             master.expect('Warm shutdown')
@@ -91,15 +92,24 @@ class KuyrukTestCase(unittest.TestCase):
         worker will spawn a new master worker.
 
         """
-        _pid = lambda: get_pid('kuyruk: worker')
-        with run_kuyruk() as master:
+        def get_worker_pids():
+            pids = get_pids('kuyruk: worker')
+            assert len(pids) == 2
+            return pids
+
+        with run_kuyruk(process='master') as master:
             master.expect('Start consuming')
-            pid1 = _pid()
-            os.kill(pid1, signal.SIGKILL)
+            master.expect('Start consuming')
+            pids_old = get_worker_pids()
+            for pid in pids_old:
+                os.kill(pid, signal.SIGKILL)
             master.expect('Spawning new worker')
             master.expect('Start consuming')
-            pid2 = _pid()
-        assert pid2 > pid1
+            master.expect('Start consuming')
+            pids_new = get_worker_pids()
+
+        assert pids_new[0] > pids_old[0]  # kuyruk
+        assert pids_new[1] > pids_old[1]  # kuryuk.localhost
 
     def test_save_failed(self):
         """Failed tasks are saved to another queue"""
@@ -110,6 +120,7 @@ class KuyrukTestCase(unittest.TestCase):
             master.expect('No retry left')
             master.expect('Saving failed task')
             master.expect('Saved')
+            master.expect('Committed transaction')
         assert is_empty('kuyruk')
         assert not is_empty('kuyruk_failed')
 
@@ -137,6 +148,13 @@ class KuyrukTestCase(unittest.TestCase):
             master.expect('function4')
             master.expect('function5')
 
+    def test_extend(self):
+        """Extend task class"""
+        tasks.use_session()
+        with run_kuyruk() as master:
+            master.expect('Opening session')
+            master.expect('Closing session')
+
     def test_class_task(self):
         cat = tasks.Cat(1, 'Felix')
         self.assertTrue(isinstance(tasks.Cat.meow, Task))
@@ -149,3 +167,9 @@ class KuyrukTestCase(unittest.TestCase):
     def test_task_name(self):
         self.assertEqual(tasks.Cat.meow.name, 'kuyruk.test.tasks:Cat.meow')
         self.assertEqual(tasks.print_task.name, 'kuyruk.test.tasks:print_task')
+
+    def test_timeout(self):
+        """Timeout long running task"""
+        tasks.sleeping_task(2)
+        with run_kuyruk() as master:
+            master.expect('raise Timeout')
